@@ -4,7 +4,7 @@
     Rosegarden
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -31,6 +31,7 @@
 #include <iomanip>
 #include <algorithm>
 #include <cmath>
+#include <typeinfo>
 
 #if (__GNUC__ < 3)
 #include <strstream>
@@ -331,6 +332,75 @@ void Composition::setSegmentStartTime(Segment *segment, timeT startTime)
     m_segments.insert(segment);    
 }
 
+int
+Composition::getMaxContemporaneousSegmentsOnTrack(TrackId track) const
+{
+    // Could be made faster, but only if it needs to be.
+
+    // This is similar to the polyphony calculation in
+    // DocumentMetaConfigurationPage ctor.
+
+    std::set<Segment *> simultaneous;
+    std::multimap<timeT, Segment *> ends;
+
+    int maximum = 0;
+
+    for (const_iterator i = begin(); i != end(); ++i) {
+	if ((*i)->getTrack() != track) continue;
+	timeT t0 = (*i)->getStartTime();
+	timeT t1 = (*i)->getRepeatEndTime();
+//	std::cerr << "getMaxContemporaneousSegmentsOnTrack(" << track << "): segment " << *i << " from " << t0 << " to " << t1 << std::endl;
+	while (!ends.empty() && t0 >= ends.begin()->first) {
+	    simultaneous.erase(ends.begin()->second);
+	    ends.erase(ends.begin());
+	}
+	simultaneous.insert(*i);
+	ends.insert(std::multimap<timeT, Segment *>::value_type(t1, *i));
+	int current = simultaneous.size();
+	if (current > maximum) maximum = current;
+    }
+
+    return maximum;
+}
+
+int
+Composition::getSegmentVoiceIndex(const Segment *segment) const
+{
+    TrackId track = segment->getTrack();
+
+    // See function above
+
+    std::map<Segment *, int> indices;
+    std::set<int> used;
+    std::multimap<timeT, Segment *> ends;
+
+    int maximum = 0;
+
+    for (const_iterator i = begin(); i != end(); ++i) {
+	if ((*i)->getTrack() != track) continue;
+	timeT t0 = (*i)->getStartTime();
+	timeT t1 = (*i)->getRepeatEndTime();
+	int index;
+	while (!ends.empty() && t0 >= ends.begin()->first) {
+	    index = indices[ends.begin()->second];
+	    used.erase(index);
+	    indices.erase(ends.begin()->second);
+	    ends.erase(ends.begin());
+	}
+	for (index = 0; ; ++index) {
+	    if (used.find(index) == used.end()) break;
+	}
+	if (*i == segment) return index;
+	indices[*i] = index;
+	used.insert(index);
+	ends.insert(std::multimap<timeT, Segment *>::value_type(t1, *i));
+    }
+
+    std::cerr << "WARNING: Composition::getSegmentVoiceIndex: segment "
+	      << segment << " not found in composition" << std::endl;
+    return 0;
+}
+
 TriggerSegmentRec *
 Composition::addTriggerSegment(Segment *s, int pitch, int velocity)
 {
@@ -523,6 +593,17 @@ Composition::calculateBarPositions() const
     timeT lastSigTime = 0;
     timeT barDuration = TimeSignature().getBarDuration();
 
+    if (getStartMarker() < 0) {
+	if (!t.empty() && (*t.begin())->getAbsoluteTime() <= 0) {
+	    barDuration = TimeSignature(**t.begin()).getBarDuration();
+	}
+	lastBarNo = getStartMarker() / barDuration;
+	lastSigTime = getStartMarker();
+#ifdef DEBUG_BAR_STUFF
+	cerr << "Composition::calculateBarPositions: start marker = " << getStartMarker() << ", so initial bar number = " << lastBarNo << endl;
+#endif
+    }
+
     for (i = t.begin(); i != t.end(); ++i) {
 
 	timeT myTime = (*i)->getAbsoluteTime();
@@ -682,6 +763,10 @@ Composition::getBarRange(int n) const
 int
 Composition::addTimeSignature(timeT t, TimeSignature timeSig)
 {
+#ifdef DEBUG_BAR_STUFF
+    cerr << "Composition::addTimeSignature(" << t << ", " << timeSig.getNumerator() << "/" << timeSig.getDenominator() << ")" << endl;
+#endif
+
     ReferenceSegment::iterator i =
 	m_timeSigSegment.insert(timeSig.getAsEvent(t));
     m_barPositionsNeedCalculating = true;
@@ -1753,14 +1838,14 @@ std::string Composition::toXmlString()
 	 i != m_tempoSegment.end(); ++i) {
 
 	tempoT tempo = tempoT((*i)->get<Int>(TempoProperty));
-	tempoT target = 0;
+	tempoT target = -1;
 	if ((*i)->has(TargetTempoProperty)) {
 	    target = tempoT((*i)->get<Int>(TargetTempoProperty));
 	}
 	composition << "  <tempo time=\"" << (*i)->getAbsoluteTime()
 		    << "\" bph=\"" << ((tempo * 6) / 10000)
 		    << "\" tempo=\"" << tempo;
-	if (target > 0) {
+	if (target >= 0) {
 	    composition << "\" target=\"" << target;
 	}
 	composition << "\"/>" << endl;
@@ -1799,7 +1884,6 @@ Composition::clearTracks()
         delete ((*it).second);
 
     m_tracks.erase(m_tracks.begin(), m_tracks.end());
-    updateRefreshStatuses();
 }
 
 Track*
@@ -1825,6 +1909,7 @@ Composition::getTrackPositionById(TrackId id) const
     return track->getPosition();
 }
 
+
 Rosegarden::TrackId
 Composition::getNewTrackId() const
 {
@@ -1952,7 +2037,17 @@ Composition::notifySegmentTrackChanged(Segment *s, TrackId oldId, TrackId newId)
 }
 
 void
-Composition::notifySegmentEndMarkerChange(Segment *s, bool shorten) const
+Composition::notifySegmentStartChanged(Segment *s, timeT t)
+{
+    updateRefreshStatuses(); // not ideal, but best way to ensure track heights are recomputed
+    for (ObserverSet::const_iterator i = m_observers.begin();
+	 i != m_observers.end(); ++i) {
+	(*i)->segmentStartChanged(this, s, t);
+    }
+}    
+
+void
+Composition::notifySegmentEndMarkerChange(Segment *s, bool shorten)
 {
     for (ObserverSet::const_iterator i = m_observers.begin();
 	 i != m_observers.end(); ++i) {
