@@ -4,7 +4,7 @@
     Rosegarden
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -165,11 +165,13 @@ namespace CompositionMetadataKeys
 // Keep these in lower case
 const PropertyName DocumentConfiguration::SequencerOptions      = "sequenceroptions";
 const PropertyName DocumentConfiguration::ZoomLevel             = "zoomlevel";
+const PropertyName DocumentConfiguration::TransportMode         = "transportmode";
 
 
 DocumentConfiguration::DocumentConfiguration()
 {
     set<Int>(ZoomLevel, 0);
+    set<String>(TransportMode, ""); // apparently generates an exception if not initialized
 }
     
 DocumentConfiguration::DocumentConfiguration(const DocumentConfiguration &conf):
@@ -211,6 +213,9 @@ DocumentConfiguration::toXmlString()
     config << "    <" << ZoomLevel << " type=\"Int\">" << get<Int>(ZoomLevel)
            << "</" << ZoomLevel << ">\n";
 
+    config << "    <" << TransportMode << " type=\"String\">" << get<String>(TransportMode)
+           << "</" << TransportMode << ">\n";
+
     config << "</configuration>" << endl;
 
 #if (__GNUC__ < 3)
