@@ -5,7 +5,7 @@
     Rosegarden
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -1027,13 +1027,15 @@ NotationQuantizer::Impl::quantizeRange(Segment *s,
     int events = 0, notes = 0, passes = 0;
     int setGood = 0, setBad = 0;
     
-//#ifdef DEBUG_NOTATION_QUANTIZER
+#ifdef DEBUG_NOTATION_QUANTIZER
     cout << "NotationQuantizer::Impl::quantizeRange: from time "
 	      << (from == s->end() ? -1 : (*from)->getAbsoluteTime())
 	      << " to "
 	      << (to == s->end() ? -1 : (*to)->getAbsoluteTime())
 	      << endl;
-//#endif
+#endif
+
+    timeT segmentEndTime = s->getEndMarkerTime();
 
     // This process does several passes over the data.  It's assumed
     // that this is not going to be invoked in any really time-critical
@@ -1182,12 +1184,16 @@ NotationQuantizer::Impl::quantizeRange(Segment *s,
 	m_q->setToTarget(s, i, t, d);
     }
     ++passes;
-
+/*
     cerr << "NotationQuantizer: " << events << " events ("
 	 << notes << " notes), " << passes << " passes, "
 	 << setGood << " good sets, " << setBad << " bad sets, "
 	 << ((clock() - start) * 1000 / CLOCKS_PER_SEC) << "ms elapsed"
 	 << endl;
+*/
+    if (s->getEndTime() < segmentEndTime) {
+	s->setEndMarkerTime(segmentEndTime);
+    }
 
     delete profiler; // on heap so it updates before the next line:
     Profiles::getInstance()->dump();
