@@ -5,7 +5,7 @@
     Rosegarden
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -92,6 +92,23 @@ namespace Accidentals
 
     typedef std::vector<Accidental> AccidentalList;
 
+	/** 
+	 * When no accidental is specified for a pitch, there are several
+	 * strategies to determine what accidental to display for an 
+	 * out-of-key pitch
+	 */
+	enum NoAccidentalStrategy {
+		/** always use sharps */
+		UseSharps,
+		/** always use flats */
+		UseFlats,
+		/** always use sharps or always use flats depending on of what
+		 * type of accidentals the current key is made up */ 
+		UseKeySharpness,
+		/** use the most likely accidental for this key */
+		UseKey
+	};
+
     /**
      * Get the predefined accidentals (i.e. the ones listed above)
      * in their defined order.
@@ -106,6 +123,16 @@ namespace Accidentals
      * the Key and Pitch classes.
      */
     extern int getPitchOffset(const Accidental &accidental);
+
+
+    /**
+     * Get the Accidental corresponding to a change in pitch: flat
+     * for -1, double-sharp for 2, natural for 0 etc.
+     *
+     * Useful for tying to code that represents accidentals by 
+     * their pitch change.
+     */
+    extern Accidental getAccidental(int pitchChange);
 }
 
 
@@ -236,10 +263,15 @@ public:
     typedef Exception BadClefName;
 
     static const std::string Treble;
+    static const std::string French;
     static const std::string Soprano;
-    static const std::string Tenor;
+    static const std::string Mezzosoprano;
     static const std::string Alto;
+    static const std::string Tenor;
+    static const std::string Baritone;
+    static const std::string Varbaritone;
     static const std::string Bass;
+    static const std::string Subbass;
 
     /**
      * Construct the default clef (treble).
@@ -282,7 +314,7 @@ public:
     static bool isValid(const Event &e);
 
     /**
-     * Return the basic clef type (Treble, Soprano, Tenor, Alto, Bass)
+     * Return the basic clef type (Treble, French, Soprano, Mezzosoprano, Alto, Tenor, Baritone, Varbaritone, Bass, Subbass)
      */
     std::string getClefType() const { return m_clef; }
 
@@ -394,6 +426,10 @@ public:
         return k.m_name == m_name;
     }
 
+    bool operator!=(const Key &k) const {
+        return !(k == *this);
+    }
+
     /**
      * Test whether the given event is a valid Key event.
      */
@@ -425,7 +461,7 @@ public:
     int getTonicPitch() const {
         return m_keyDetailMap[m_name].m_tonicPitch;
     }
-
+    
     /**
      * Return the number of sharps or flats in the key's signature.
      */
@@ -463,6 +499,13 @@ public:
      */
     Accidental getAccidentalAtHeight(int height, const Clef &clef) const;
 
+    /**
+     * Return the accidental for the the given number of steps
+     * from the tonic. For example: for F major, step '3' is the
+     * Bb, so getAccidentalForStep(3) will yield a Flat.
+     */
+    Accidental getAccidentalForStep(int steps) const;
+
     /**
      * Return the heights-on-staff (in Pitch
      * terminology) of all accidentals in the key's signature,
@@ -509,6 +552,14 @@ public:
     /// Returned event is on heap; caller takes responsibility for ownership
     Event *getAsEvent(timeT absoluteTime) const;
 
+    /**
+     * Transpose this key by the specified interval given in pitch and steps
+     * 
+     * For example: transposing F major by a major triad (4,2) yields
+     *  A major.
+     */
+    Key transpose(int pitchDelta, int heightDelta);
+
 private:
     std::string m_name;
     mutable std::vector<int> *m_accidentalHeights;
@@ -620,6 +671,7 @@ public:
     static const int EventSubOrdering;
     static const PropertyName TextPropertyName;
     static const PropertyName TextTypePropertyName;
+    static const PropertyName LyricVersePropertyName;
 
     /**
      * Text styles
@@ -636,10 +688,10 @@ public:
     static const std::string Tempo;
     static const std::string LocalTempo;
     static const std::string Annotation;
-    static const std::string LilypondDirective;
+    static const std::string LilyPondDirective;
 
     /**
-     * Special Lilypond directives
+     * Special LilyPond directives
      */
     static const std::string Segno;       // print segno here
     static const std::string Coda;        // print coda sign here
@@ -667,6 +719,9 @@ public:
     std::string getText() const { return m_text; }
     std::string getTextType() const { return m_type; }
 
+    int getVerse() const { return m_verse; } // only relevant for lyrics
+    void setVerse(int verse) { m_verse = verse; }
+
     static bool isTextOfType(Event *, std::string type);
 
     /**
@@ -676,9 +731,9 @@ public:
     static std::vector<std::string> getUserStyles();
 
     /**
-     * Return a list of available special Lilypond directives
+     * Return a list of available special LilyPond directives
      */
-    static std::vector<std::string> getLilypondDirectives();
+    static std::vector<std::string> getLilyPondDirectives();
 
     /// Returned event is on heap; caller takes responsibility for ownership
     Event *getAsEvent(timeT absoluteTime) const;
@@ -686,6 +741,7 @@ public:
 private:
     std::string m_text;
     std::string m_type;
+    long m_verse;
 };
 
 
@@ -745,6 +801,14 @@ public:
           const Accidental &explicitAccidental = Accidentals::NoAccidental,
           int octaveBase = -2);
 
+    /**
+     * Construct a Pitch based on (MIDI) octave, note in the C major scale and 
+     * performance pitch. The accidental is calculated based on these
+     * properties.
+     */
+    Pitch(int noteInCMajor, int octave, int pitch,
+          int octaveBase = -2);
+
     /**
      * Construct a Pitch based on octave and note name.  The lowest
      * permissible octave number is octaveBase, and middle C is in
@@ -784,7 +848,7 @@ public:
      * This version of the function exists to avoid breaking old code.
      */
     Accidental getAccidental(bool useSharps) const;
-    
+
     /**
      * Return the accidental for this pitch, using a key.  This should be used
      * if you need an explicit accidental returned for E#, Fb, B# or Cb, which
@@ -804,6 +868,13 @@ public:
      */
     Accidental getDisplayAccidental(const Key &key) const;
 
+	/**
+     * Return the accidental that should be used to display this pitch
+     * in a given key, using the given strategy to resolve pitches where
+     * an accidental is needed but not specified.
+     */
+    Accidental getDisplayAccidental(const Key &key, Accidentals::NoAccidentalStrategy) const;
+
     /**
      * Return the position in the scale for this pitch, as a number in
      * the range 0 to 6 where 0 is the root of the key.
@@ -822,9 +893,21 @@ public:
      * conventional 5-line staff.  0 is the bottom line, 1 the first
      * space, etc., so for example middle-C in the treble clef would
      * return -2.
+     *
+     * Chooses the most likely accidental for this pitch in this key.
      */
     int getHeightOnStaff(const Clef &clef, const Key &key) const;
 
+    /**
+     * Return the height at which this pitch should display on a
+     * conventional 5-line staff.  0 is the bottom line, 1 the first
+     * space, etc., so for example middle-C in the treble clef would
+     * return -2.
+     *
+     * Chooses the accidental specified by the 'useSharps' parameter
+     */
+    int getHeightOnStaff(const Clef &clef, bool useSharps) const;
+
     /**
      * Return the octave containing this pitch.  The octaveBase argument
      * specifies the octave containing MIDI pitch 0; middle-C is in octave
@@ -882,12 +965,32 @@ public:
                                                 const Clef &clef,
                                                 const Key &key);
 
+    /**
+     * return the result of transposing the given pitch by the
+     * specified interval in the given key. The key is left unchanged,
+     * only the pitch is transposed.
+     */
+    Pitch transpose(const Key &key, int pitchDelta, int heightDelta);
+
+    /** 
+      * checks whether the accidental specified for this pitch (if any)
+      * is valid - for example, a Sharp for pitch 11 is invalid, as
+      * it's between A# and B#.
+      */  
+    bool validAccidental() const;
+
+    /**
+     * Returned event is on heap; caller takes responsibility for ownership
+     */
+    Event *getAsNoteEvent(timeT absoluteTime, timeT duration) const;
+
 private:
     int m_pitch;
     Accidental m_accidental;
 
     static void rawPitchToDisplayPitch
-    (int, const Clef &, const Key &, int &, Accidental &);
+    (int, const Clef &, const Key &, int &, Accidental &, 
+    Accidentals::NoAccidentalStrategy);
 
     static void displayPitchToRawPitch
     (int, Accidental, const Clef &, const Key &,
