@@ -4,7 +4,7 @@
     Rosegarden
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -242,6 +242,9 @@ Segment::setStartTime(timeT t)
     for (int i = 0; i < events.size(); ++i) {
 	insert(events[i]);
     }
+
+    notifyStartChanged(m_startTime);
+    updateRefreshStatuses(m_startTime, m_endTime);
 }
 
 void
@@ -366,11 +369,14 @@ Segment::insert(Event *e)
 
         if (m_composition) m_composition->setSegmentStartTime(this, t0);
 	else m_startTime = t0;
+	notifyStartChanged(m_startTime);
     }
 
     if (t1 > m_endTime ||
 	begin() == end()) {
+	timeT oldTime = m_endTime;
 	m_endTime = t1;
+	notifyEndMarkerChange(m_endTime < oldTime);
     }
 
     iterator i = std::multiset<Event*, Event::EventCmp>::insert(e);
@@ -411,6 +417,7 @@ Segment::erase(iterator pos)
 	timeT startTime = (*begin())->getAbsoluteTime();
         if (m_composition) m_composition->setSegmentStartTime(this, startTime);
 	else m_startTime = startTime;
+	notifyStartChanged(m_startTime);
     }
     if (t1 == m_endTime) {
 	updateEndTime();
@@ -447,6 +454,7 @@ Segment::erase(iterator from, iterator to)
 	timeT startTime = (*begin())->getAbsoluteTime();
         if (m_composition) m_composition->setSegmentStartTime(this, startTime);
 	else m_startTime = startTime;
+	notifyStartChanged(m_startTime);
     }
 
     if (endTime == m_endTime) {
@@ -543,6 +551,7 @@ Segment::fillWithRests(timeT startTime, timeT endTime)
     if (startTime < m_startTime) {
         if (m_composition) m_composition->setSegmentStartTime(this, startTime);
 	else m_startTime = startTime;
+	notifyStartChanged(m_startTime);
     }
 
     TimeSignature ts;
@@ -590,6 +599,7 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
 #endif
         if (m_composition) m_composition->setSegmentStartTime(this, startTime);
 	else m_startTime = startTime;
+	notifyStartChanged(m_startTime);
     }
 
     //!!! Need to remove the rests then relocate the start time
@@ -742,10 +752,14 @@ Segment::normalizeRests(timeT startTime, timeT endTime)
 
     for (; i != ib && i != end(); ++i) {
 
-	// if we have any rests remaining in this area, treat them
-	// as "hard" rests (they had tuplet data, so we don't want to
-	// disturb them)
-	if (!((*i)->isa(Note::EventType) || (*i)->isa(Note::EventRestType))) {
+	// Boundary events for sets of rests may be notes (obviously),
+	// text events (because they need to be "attached" to
+	// something that has the correct timing), or rests (any
+	// remaining rests in this area have tuplet data so should be
+	// treated as "hard" rests);
+	if (!((*i)->isa(Note::EventType) ||
+	      (*i)->isa(Text::EventType) ||
+	      (*i)->isa(Note::EventRestType))) {
 	    continue;
 	}
 
@@ -1063,20 +1077,58 @@ Segment::getKeyAtTime(timeT time, timeT &ktime) const
     }
 }
 
+void
+Segment::getFirstClefAndKey(Clef &clef, Key &key)
+{
+    bool keyFound = false;
+    bool clefFound = false;
+    clef = Clef();          // Default clef
+    key = Key();            // Default key signature
+
+    iterator i = begin();
+    while (i!=end()) {
+        // Keep current clef and key as soon as a note or rest event is found
+        if ((*i)->isa(Note::EventRestType) || (*i)->isa(Note::EventType)) return;
+
+        // Remember the first clef event found
+        if ((*i)->isa(Clef::EventType)) {
+            clef = Clef(*(*i));
+            // and return if a key has already been found
+            if (keyFound) return;
+            clefFound = true;
+        }
+
+        // Remember the first key event found
+        if ((*i)->isa(Key::EventType)) {
+            key = Key(*(*i));
+            // and return if a clef has already been found
+            if (clefFound) return;
+            keyFound = true;
+        }
+
+        ++i;
+    }
+}
+
 timeT
 Segment::getRepeatEndTime() const
 {
+    timeT endMarker = getEndMarkerTime();
+
     if (m_repeating && m_composition) {
 	Composition::iterator i(m_composition->findSegment(this));
 	assert(i != m_composition->end());
 	++i;
 	if (i != m_composition->end() && (*i)->getTrack() == getTrack()) {
-	    return (*i)->getStartTime();
+	    timeT t = (*i)->getStartTime();
+	    if (t < endMarker) return endMarker;
+	    else return t;
 	} else {
             return m_composition->getEndMarker();
 	}
     }
-    return getEndMarkerTime();
+
+    return endMarker;
 }
 
 
@@ -1125,6 +1177,19 @@ Segment::notifyAppearanceChange() const
     }
 }
 
+void
+Segment::notifyStartChanged(timeT newTime)
+{
+    for (ObserverSet::const_iterator i = m_observers.begin();
+	 i != m_observers.end(); ++i) {
+	(*i)->startChanged(this, newTime);
+    }
+    if (m_composition) {
+	m_composition->notifySegmentStartChanged(this, newTime);
+    }
+}
+    
+
 void
 Segment::notifyEndMarkerChange(bool shorten)
 {
