@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -61,7 +61,7 @@ PasteEventsCommand::PasteEventsCommand(Segment &segment,
             Segment *s(clipboard->getSingleSegment());
             for (Segment::iterator i = s->begin(); i != s->end(); ++i) {
                 if ((*i)->isa(Clef::EventType) ||
-                        (*i)->isa(Key::EventType)) {
+                    (*i)->isa(Key::EventType)) {
                     m_relayoutEndTime = s->getEndTime();
                     break;
                 }
@@ -247,10 +247,8 @@ PasteEventsCommand::modifySegment()
                 continue;
             Event *e = (*i)->copyMoving(pasteTime - origin);
             if (e->has(BEAMED_GROUP_ID)) {
-                e->set
-                <Int>(BEAMED_GROUP_ID,
-                      groupIdMap[e->get
-                                 <Int>(BEAMED_GROUP_ID)]);
+                e->set<Int>(BEAMED_GROUP_ID,
+                            groupIdMap[e->get<Int>(BEAMED_GROUP_ID)]);
             }
             if ((*i)->isa(Note::EventType)) {
                 // e is model event: we retain ownership of it
