@@ -5,7 +5,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -234,6 +234,10 @@ public:
      */
     bool isRegularDotRGFile();
 
+    void setQuickMarker();
+    void jumpToQuickMarker();    
+    timeT getQuickMarkerTime() { return m_quickMarkerTime; }
+
     /**
      * returns the global command history
      */
@@ -501,6 +505,8 @@ signals:
      */
     void newAudioRecordingSegment(Segment*);
 
+    void makeTrackVisible(int trackPosition);
+
     void stoppedAudioRecording();
     void stoppedMIDIRecording();
     void audioFileFinalized(Segment*);
@@ -708,6 +714,8 @@ protected:
 
     timeT m_recordStartTime;
 
+    timeT m_quickMarkerTime;
+
     std::vector<QString> m_orphanedRecordedAudioFiles;
     std::vector<QString> m_orphanedDerivedAudioFiles;
 
