@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -26,7 +26,7 @@
 #include "StartupTester.h"
 
 #include "misc/Debug.h"
-#include "gui/dialogs/LilypondOptionsDialog.h"
+#include "gui/dialogs/LilyPondOptionsDialog.h"
 
 #include <kprocess.h>
 #include <qmutex.h>
@@ -40,9 +40,18 @@ namespace Rosegarden
 StartupTester::StartupTester() :
     m_ready(false),
     m_haveProjectPackager(false),
-    m_haveLilypondView(false),
+    m_haveLilyPondView(false),
     m_haveAudioFileImporter(false)
-{}
+{
+    QHttp *http = new QHttp();
+    connect(http, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)),
+            this, SLOT(slotHttpResponseHeaderReceived(const QHttpResponseHeader &)));
+    connect(http, SIGNAL(done(bool)),
+            this, SLOT(slotHttpDone(bool)));
+    m_versionHttpFailed = false;
+    http->setHost("www.rosegardenmusic.com");
+    http->get("/latest-version.txt");
+}
 
 StartupTester::~StartupTester()
 {
@@ -52,7 +61,7 @@ void
 StartupTester::run()
 {
     m_projectPackagerMutex.lock();
-    m_lilypondViewMutex.lock();
+    m_lilyPondViewMutex.lock();
     m_audioFileImporterMutex.lock();
     m_ready = true;
 
@@ -103,18 +112,18 @@ StartupTester::run()
     proc->start(KProcess::Block, KProcess::All);
     if (!proc->normalExit() || proc->exitStatus()) {
         RG_DEBUG << "StartupTester - No lilypondview available" << endl;
-        m_haveLilypondView = false;
-        parseStdoutBuffer(m_lilypondViewMissing);
+        m_haveLilyPondView = false;
+        parseStdoutBuffer(m_lilyPondViewMissing);
     } else {
-        RG_DEBUG << "StartupTester - Lilypondview OK" << endl;
-        m_haveLilypondView = true;
-        QRegExp re("Lilypond version: ([^\n]*)");
+        RG_DEBUG << "StartupTester - lilypondview OK" << endl;
+        m_haveLilyPondView = true;
+        QRegExp re("LilyPond version: ([^\n]*)");
         if (re.search(m_stdoutBuffer) != -1) {
-            LilypondOptionsDialog::setDefaultLilypondVersion(re.cap(1));
+            LilyPondOptionsDialog::setDefaultLilyPondVersion(re.cap(1));
         }
     }
     delete proc;
-    m_lilypondViewMutex.unlock();
+    m_lilyPondViewMutex.unlock();
 }
 
 bool
@@ -127,8 +136,8 @@ StartupTester::isReady()
     } else {
         return false;
     }
-    if (m_lilypondViewMutex.tryLock()) {
-        m_lilypondViewMutex.unlock();
+    if (m_lilyPondViewMutex.tryLock()) {
+        m_lilyPondViewMutex.unlock();
     } else {
         return false;
     }
@@ -161,13 +170,13 @@ StartupTester::haveProjectPackager(QStringList *missing)
 }
 
 bool
-StartupTester::haveLilypondView(QStringList *missing)
+StartupTester::haveLilyPondView(QStringList *missing)
 {
     while (!m_ready)
         usleep(10000);
-    QMutexLocker locker(&m_lilypondViewMutex);
-    if (missing) *missing = m_lilypondViewMissing;
-    return m_haveLilypondView;
+    QMutexLocker locker(&m_lilyPondViewMutex);
+    if (missing) *missing = m_lilyPondViewMissing;
+    return m_haveLilyPondView;
 }
 
 bool
@@ -180,6 +189,60 @@ StartupTester::haveAudioFileImporter(QStringList *missing)
     return m_haveAudioFileImporter;
 }
 
+bool
+StartupTester::isVersionNewerThan(QString a, QString b)
+{
+    QRegExp re("[._-]");
+    QStringList alist = QStringList::split(re, a);
+    QStringList blist = QStringList::split(re, b);
+    int ae = alist.size();
+    int be = blist.size();
+    int e = std::max(ae, be);
+    for (int i = 0; i < e; ++i) {
+	int an = 0, bn = 0;
+	if (i < ae) {
+	    an = alist[i].toInt();
+	    if (an == 0) an = -1; // non-numeric field -> "-pre1" etc
+	}
+	if (i < be) {
+	    bn = blist[i].toInt();
+	    if (bn == 0) bn = -1;
+	}
+	if (an < bn) return false;
+	if (an > bn) return true;
+    }
+    return false;
+}
+
+void
+StartupTester::slotHttpResponseHeaderReceived(const QHttpResponseHeader &h)
+{
+    if (h.statusCode() / 100 != 2) m_versionHttpFailed = true;
+}
+
+void
+StartupTester::slotHttpDone(bool error)
+{
+    QHttp *http = const_cast<QHttp *>(dynamic_cast<const QHttp *>(sender()));
+    if (!http) return;
+    http->deleteLater();
+    if (error) return;
+
+    QByteArray responseData = http->readAll();
+    QString str = QString::fromUtf8(responseData.data());
+    QStringList lines = QStringList::split('\n', str);
+    if (lines.empty()) return;
+
+    QString latestVersion = lines[0];
+    std::cerr << "Comparing current version \"" << VERSION
+              << "\" with latest version \"" << latestVersion << "\""
+              << std::endl;
+    if (isVersionNewerThan(latestVersion, VERSION)) {
+        emit newerVersionAvailable(latestVersion);
+    }
+}
+
 }
 
 #include "StartupTester.moc"
+
