@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -33,6 +33,7 @@
 #include "commands/edit/PasteEventsCommand.h"
 #include "ConfigurationPage.h"
 #include "document/RosegardenGUIDoc.h"
+#include "gui/editors/notation/HeadersGroup.h"
 #include "gui/editors/notation/NotationHLayout.h"
 #include "gui/editors/notation/NoteFontFactory.h"
 #include "gui/editors/notation/NoteFont.h"
@@ -59,7 +60,8 @@
 #include <qstringlist.h>
 #include <qtabwidget.h>
 #include <qwidget.h>
-
+#include <qtooltip.h>
+#include <algorithm>
 
 namespace Rosegarden
 {
@@ -147,6 +149,27 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
     layout->addMultiCellWidget(m_proportion, row, row, 1, 2);
     ++row;
 
+    layout->addWidget(new QLabel(i18n("Show track headers (linear layout only)"),
+                                      frame), row, 0);
+
+    m_showTrackHeaders = new KComboBox(frame);
+    m_showTrackHeaders->setEditable(false);
+    m_showTrackHeaders->insertItem(i18n("Never"), HeadersGroup::ShowNever);
+    m_showTrackHeaders->insertItem(i18n("When needed"), HeadersGroup::ShowWhenNeeded);
+    m_showTrackHeaders->insertItem(i18n("Always"), HeadersGroup::ShowAlways);
+    int defaultShowTrackHeaders = m_cfg->readNumEntry("shownotationheader", 
+                                                 HeadersGroup::DefaultShowMode);
+    if (HeadersGroup::isValidShowMode(defaultShowTrackHeaders)) {
+        m_showTrackHeaders->setCurrentItem(defaultShowTrackHeaders);
+    }
+    QToolTip::add(m_showTrackHeaders, QString(i18n(
+        "\"Always\" and \"Never\" mean what they usually mean\n"
+        "\"When needed\" means \"when staves are too many to all fit"
+        " in the current window\"")));
+
+    layout->addMultiCellWidget(m_showTrackHeaders, row, row, 1, 2);
+    ++row;
+
     layout->setRowSpacing(row, 20);
     ++row;
 
@@ -215,6 +238,7 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
 
     layout->setRowStretch(row, 10);
 
+
     addTab(frame, i18n("Layout"));
 
 
@@ -510,30 +534,37 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
     ++row;
 
     QFont defaultTextFont(NotePixmapFactory::defaultSerifFontFamily),
-    defaultTimeSigFont(NotePixmapFactory::defaultTimeSigFontFamily);
+        defaultSansFont(NotePixmapFactory::defaultSansSerifFontFamily),
+        defaultTimeSigFont(NotePixmapFactory::defaultTimeSigFontFamily);
 
-//    frame = new QFrame(otherFontBox);
-//    QGridLayout *otherLayout = new QGridLayout(frame, 2, 2, 10, 5);
-
-//    otherLayout->addWidget
     layout->addWidget
         (new QLabel(i18n("Text font"), frame), row, 0);
     m_textFont = new KFontRequester(frame);
     QFont textFont = m_cfg->readFontEntry("textfont", &defaultTextFont);
     m_textFont->setFont(textFont);
-//    otherLayout->addWidget(m_textFont, 0, 1);
     layout->addMultiCellWidget(m_textFont, row, row, 1, 3);
     ++row;
 
-//    otherLayout->addWidget
+    layout->addWidget
+        (new QLabel(i18n("Sans-serif font"), frame), row, 0);
+    m_sansFont = new KFontRequester(frame);
+    QFont sansFont = m_cfg->readFontEntry("sansfont", &defaultSansFont);
+    m_sansFont->setFont(sansFont);
+    layout->addMultiCellWidget(m_sansFont, row, row, 1, 3);
+    ++row;
+
+/*!!! No -- not much point in having the time sig font here: it's only
+ * used if the time sig characters are not found in the notation font,
+ * and our default notation font has all the characters we need
+
     layout->addWidget
         (new QLabel(i18n("Time Signature font"), frame), row, 0);
     m_timeSigFont = new KFontRequester(frame);
     QFont timeSigFont = m_cfg->readFontEntry("timesigfont", &defaultTimeSigFont);
     m_timeSigFont->setFont(timeSigFont);
-//    otherLayout->addWidget(m_timeSigFont, 1, 1);
     layout->addMultiCellWidget(m_timeSigFont, row, row, 1, 3);
     ++row;
+*/
 
 //    addTab(mainFrame, i18n("Font"));
     addTab(frame, i18n("Font"));
@@ -672,9 +703,12 @@ NotationConfigurationPage::apply()
                       m_printingSize->currentText().toUInt());
     m_cfg->writeEntry("textfont",
                       m_textFont->font());
+    m_cfg->writeEntry("sansfont",
+                      m_sansFont->font());
+/*!!!
     m_cfg->writeEntry("timesigfont",
                       m_timeSigFont->font());
-
+*/
     std::vector<int> s = NotationHLayout::getAvailableSpacings();
     m_cfg->writeEntry("spacing", s[m_spacing->currentItem()]);
 
@@ -687,6 +721,8 @@ NotationConfigurationPage::apply()
     m_cfg->writeEntry("showinvisibles", m_showInvisibles->isChecked());
     m_cfg->writeEntry("showranges", m_showRanges->isChecked());
     m_cfg->writeEntry("showcollisions", m_showCollisions->isChecked());
+    m_cfg->writeEntry("shownotationheader",
+                       m_showTrackHeaders->currentItem());
     m_cfg->writeEntry("style", m_untranslatedNoteStyle[m_noteStyle->currentItem()]);
     m_cfg->writeEntry("inserttype", m_insertType->currentItem());
     m_cfg->writeEntry("autobeam", m_autoBeam->isChecked());
