@@ -5,7 +5,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -79,6 +79,7 @@ protected:
     QComboBox *m_multiStaffSize;
     QComboBox *m_printingSize;
     KFontRequester* m_textFont;
+    KFontRequester* m_sansFont;
     KFontRequester* m_timeSigFont;
     QPushButton *m_viewButton;
     QLabel *m_fontOriginLabel;
@@ -93,6 +94,7 @@ protected:
     QCheckBox *m_showInvisibles;
     QCheckBox *m_showRanges;
     QCheckBox *m_showCollisions;
+    QComboBox *m_showTrackHeaders;
     QComboBox *m_noteStyle;
     QComboBox *m_insertType;
     QCheckBox *m_autoBeam;
