@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -168,7 +168,14 @@ void MatrixSelector::handleLeftButtonPress(timeT time,
                                               e,
                                               element);
         return ;
+
+    } else if (e->state() & Qt::ControlButton) {
+
+        handleMidButtonPress(time, height, staffNo, e, element);
+        return;
+
     } else {
+
         // Workaround for #930420 Positional error in sweep-selection box
         // boundary
         int zoomValue = (int)m_matrixView->m_hZoomSlider->getCurrentSize();
