@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -92,8 +92,8 @@ NotationSelector::NotationSelector(NotationView* view)
     // commenting it out, but leaving it here in case I change my mind about
     // fooling with it.)  (DMM)
     //    new KAction(i18n("Normalize Rests"), 0, 0, this,
-    //		SLOT(slotCollapseRests()), actionCollection(),
-    //		"collapse_rests");
+    //                SLOT(slotCollapseRests()), actionCollection(),
+    //                "collapse_rests");
 
     new KAction(i18n("Collapse Rests"), 0, 0, this,
                 SLOT(slotCollapseRestsHard()), actionCollection(),
@@ -119,6 +119,14 @@ NotationSelector::NotationSelector(NotationView* view)
                 SLOT(slotInterpret()), actionCollection(),
                 "interpret");
 
+    new KAction(i18n("Move to Staff Above"), 0, 0, this,
+                SLOT(slotStaffAbove()), actionCollection(),
+                "move_events_up_staff");
+
+    new KAction(i18n("Move to Staff Below"), 0, 0, this,
+                SLOT(slotStaffBelow()), actionCollection(),
+                "move_events_down_staff");
+
     new KAction(i18n("Make Invisible"), 0, 0, this,
                 SLOT(slotMakeInvisible()), actionCollection(),
                 "make_invisible");
@@ -141,7 +149,8 @@ void NotationSelector::handleLeftButtonPress(timeT t,
         QMouseEvent* e,
         ViewElement *element)
 {
-    NOTATION_DEBUG << "NotationSelector::handleMousePress: time is " << t << ", staffNo is " << staffNo << ", e and element are " << e << " and " << element << endl;
+    std::cerr << "NotationSelector::handleMousePress: time is " << t << ", staffNo is "
+              << staffNo << ", e and element are " << e << " and " << element << std::endl;
 
     if (m_justSelectedBar) {
         handleMouseTripleClick(t, height, staffNo, e, element);
@@ -182,6 +191,35 @@ void NotationSelector::handleLeftButtonPress(timeT t,
     //m_parentView->setCursorPosition(p.x());
 }
 
+void NotationSelector::handleRightButtonPress(timeT t,
+        int height,
+        int staffNo,
+        QMouseEvent* e,
+        ViewElement *element)
+{
+    std::cerr << "NotationSelector::handleRightButtonPress" << std::endl;
+
+    const EventSelection *sel = m_nParentView->getCurrentSelection();
+
+    if (!sel || sel->getSegmentEvents().empty()) {
+
+        // if nothing selected, permit the possibility of selecting
+        // something before showing the menu
+
+        if (element) {
+            m_clickedElement = dynamic_cast<NotationElement*>(element);
+            m_selectedStaff = getStaffForElement(m_clickedElement);
+            m_nParentView->setSingleSelectedEvent
+                (m_selectedStaff->getId(), m_clickedElement->event(),
+                 true, true);
+        }
+
+        handleLeftButtonPress(t, height, staffNo, e, element);
+    }
+
+    EditTool::handleRightButtonPress(t, height, staffNo, e, element);
+}
+
 void NotationSelector::slotClickTimeout()
 {
     m_justSelectedBar = false;
@@ -326,7 +364,7 @@ void NotationSelector::handleMouseRelease(timeT, int, QMouseEvent *e)
             !m_startedFineDrag) {
 
         if (m_clickedElement != 0 && m_selectedStaff) {
-
+            
             // If we didn't drag out a meaningful area, but _did_
             // click on an individual event, then select just that
             // event
@@ -335,7 +373,14 @@ void NotationSelector::handleMouseRelease(timeT, int, QMouseEvent *e)
                     m_selectionToMerge->getSegment() ==
                     m_selectedStaff->getSegment()) {
 
-                m_selectionToMerge->addEvent(m_clickedElement->event());
+                // if the event was already part of the selection, we want to
+                // remove it
+                if (m_selectionToMerge->contains(m_clickedElement->event())) {
+                    m_selectionToMerge->removeEvent(m_clickedElement->event());
+                } else {
+                    m_selectionToMerge->addEvent(m_clickedElement->event());
+                }
+                
                 m_nParentView->setCurrentSelection(m_selectionToMerge,
                                                    true, true);
                 m_selectionToMerge = 0;
@@ -347,15 +392,15 @@ void NotationSelector::handleMouseRelease(timeT, int, QMouseEvent *e)
                  true, true);
             }
             /*
-            	} else if (m_selectedStaff) {
+                    } else if (m_selectedStaff) {
              
-            	    // If we clicked on no event but on a staff, move the
-            	    // insertion cursor to the point where we clicked. 
-            	    // Actually we only really want this to happen if
-            	    // we aren't double-clicking -- consider using a timer
-            	    // to establish whether a double-click is going to happen
+                        // If we clicked on no event but on a staff, move the
+                        // insertion cursor to the point where we clicked. 
+                        // Actually we only really want this to happen if
+                        // we aren't double-clicking -- consider using a timer
+                        // to establish whether a double-click is going to happen
              
-            	    m_nParentView->slotSetInsertCursorPosition(e->x(), (int)e->y());
+                        m_nParentView->slotSetInsertCursorPosition(e->x(), (int)e->y());
             */
         } else {
             setViewCurrentSelection(false);
@@ -484,11 +529,12 @@ void NotationSelector::drag(int x, int y, bool final)
     if (!final && !singleNonNotePreview) {
 
         if ((pitch != m_lastDragPitch || dragTime != m_lastDragTime) &&
-                m_clickedElement->isNote()) {
+            m_clickedElement->isNote()) {
 
             m_nParentView->showPreviewNote(targetStaff->getId(),
                                            layoutX, pitch, height,
-                                           Note::getNearestNote(duration));
+                                           Note::getNearestNote(duration),
+                                           m_clickedElement->isGrace());
             m_lastDragPitch = pitch;
             m_lastDragTime = dragTime;
         }
@@ -725,6 +771,16 @@ void NotationSelector::slotInterpret()
     m_parentView->actionCollection()->action("interpret")->activate();
 }
 
+void NotationSelector::slotStaffAbove()
+{
+    m_parentView->actionCollection()->action("move_events_up_staff")->activate();
+}
+
+void NotationSelector::slotStaffBelow()
+{
+    m_parentView->actionCollection()->action("move_events_down_staff")->activate();
+}
+
 void NotationSelector::slotMakeInvisible()
 {
     m_parentView->actionCollection()->action("make_invisible")->activate();
@@ -787,46 +843,46 @@ EventSelection* NotationSelector::getSelection()
     if (!m_selectedStaff) {
 
         // Scan the list of collisions, looking for a valid notation
-    // element; if we find one, initialise m_selectedStaff from it.
-    // If we don't find one, we have no selection.  This is a little
-    // inefficient but we only do it for the first event in the
-    // selection.
+        // element; if we find one, initialise m_selectedStaff from it.
+        // If we don't find one, we have no selection.  This is a little
+        // inefficient but we only do it for the first event in the
+        // selection.
 
-    for (it = itemList.begin(); it != itemList.end(); ++it) {
-        
-        if ((sprite = dynamic_cast<QCanvasNotationSprite*>(*it))) {
+        for (it = itemList.begin(); it != itemList.end(); ++it) {
+            
+            if ((sprite = dynamic_cast<QCanvasNotationSprite*>(*it))) {
 
-        NotationElement &el = sprite->getNotationElement();
+            NotationElement &el = sprite->getNotationElement();
 
-        NotationStaff *staff = getStaffForElement(&el);
-        if (!staff) continue;
-        
-        int x = (int)(*it)->x();
-        bool shifted = false;
-        int nbw = staff->getNotePixmapFactory(false).getNoteBodyWidth();
+            NotationStaff *staff = getStaffForElement(&el);
+            if (!staff) continue;
+            
+            int x = (int)(*it)->x();
+            bool shifted = false;
+            int nbw = staff->getNotePixmapFactory(false).getNoteBodyWidth();
 
-        
-        // #957364 (Notation: Hard to select upper note in
-        // chords of seconds) -- adjust x-coord for shifted
-        // note head
-        if (el.event()->get<Rosegarden::Bool>
-            (staff->getProperties().NOTE_HEAD_SHIFTED, shifted) && shifted) {
-            x += nbw;
-        }
+            
+            // #957364 (Notation: Hard to select upper note in
+            // chords of seconds) -- adjust x-coord for shifted
+            // note head
+            if (el.event()->get<Rosegarden::Bool>
+                (staff->getProperties().NOTE_HEAD_SHIFTED, shifted) && shifted) {
+                x += nbw;
+            }
 
-        if (!rect.contains(x, int((*it)->y()), true)) {
-            // #988217 (Notation: Special column of pixels
-            // prevents sweep selection) -- for notes, test
-            // again with centred x-coord
-            if (!el.isNote() || !rect.contains(x + nbw/2, int((*it)->y()), true)) {
-            continue;
+            if (!rect.contains(x, int((*it)->y()), true)) {
+                // #988217 (Notation: Special column of pixels
+                // prevents sweep selection) -- for notes, test
+                // again with centred x-coord
+                if (!el.isNote() || !rect.contains(x + nbw/2, int((*it)->y()), true)) {
+                    continue;
+                }
+            }
+                
+            m_selectedStaff = staff;
+            break;
             }
         }
-            
-        m_selectedStaff = staff;
-        break;
-        }
-    }
     }
 
     if (!m_selectedStaff) return 0;
@@ -843,7 +899,7 @@ EventSelection* NotationSelector::getSelection()
     EventSelection *selection = new EventSelection(originalSegment,
                                originalSegment.getStartTime(),
                                originalSegment.getEndMarkerTime());
-    return selection;
+        return selection;
     }
     
     EventSelection* selection = new EventSelection(originalSegment);
@@ -852,45 +908,46 @@ EventSelection* NotationSelector::getSelection()
 
         if ((sprite = dynamic_cast<QCanvasNotationSprite*>(*it))) {
 
-        NotationElement &el = sprite->getNotationElement();
-        
-        int x = (int)(*it)->x();
-        bool shifted = false;
-        int nbw = m_selectedStaff->getNotePixmapFactory(false).getNoteBodyWidth();
+            NotationElement &el = sprite->getNotationElement();
+            
+            int x = (int)(*it)->x();
+            bool shifted = false;
+            int nbw = m_selectedStaff->getNotePixmapFactory(false).getNoteBodyWidth();
 
-        // #957364 (Notation: Hard to select upper note in chords
-        // of seconds) -- adjust x-coord for shifted note head
-        if (el.event()->get<Rosegarden::Bool>
-        (m_selectedStaff->getProperties().NOTE_HEAD_SHIFTED, shifted) && shifted) {
-        x += nbw;
-        }
+            // #957364 (Notation: Hard to select upper note in chords
+            // of seconds) -- adjust x-coord for shifted note head
+            if (el.event()->get<Rosegarden::Bool>
+                            (m_selectedStaff->getProperties().NOTE_HEAD_SHIFTED, shifted)
+                            && shifted) {
+                x += nbw;
+            }
 
             // check if the element's rect
             // is actually included in the selection rect.
             //
             if (!rect.contains(x, int((*it)->y()), true))  {
-        // #988217 (Notation: Special column of pixels
-        // prevents sweep selection) -- for notes, test again
-        // with centred x-coord
-        if (!el.isNote() || !rect.contains(x + nbw/2, int((*it)->y()), true)) {
-            continue;
-        }
-        }
-            
-        // must be in the same segment as we first started on,
-        // we can't select events across multiple segments
-        if (selection->getSegment().findSingle(el.event()) !=
-        selection->getSegment().end()) {
-        selection->addEvent(el.event());
-        }
+                // #988217 (Notation: Special column of pixels
+                // prevents sweep selection) -- for notes, test again
+                // with centred x-coord
+                if (!el.isNote() || !rect.contains(x + nbw/2, int((*it)->y()), true)) {
+                    continue;
+                }
+            }
+                
+            // must be in the same segment as we first started on,
+            // we can't select events across multiple segments
+            if (selection->getSegment().findSingle(el.event()) !=
+            selection->getSegment().end()) {
+                selection->addEvent(el.event());
+            }
         }
     }
 
     if (selection->getAddedEvents() > 0) {
-    return selection;
+        return selection;
     } else {
-    delete selection;
-    return 0;
+        delete selection;
+        return 0;
     }
 }
 
