@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -75,9 +75,9 @@ EditTool* NotationToolBox::createTool(const QString& toolName)
 
         tool = new GuitarChordInserter(m_nParentView);
 
-/*    else if (toolNamelc == LilypondDirectiveInserter::ToolName)
+/*    else if (toolNamelc == LilyPondDirectiveInserter::ToolName)
 
-        tool = new LilypondDirectiveInserter(m_nParentView);*/
+        tool = new LilyPondDirectiveInserter(m_nParentView);*/
 
     else if (toolNamelc == NotationEraser::ToolName)
 
