@@ -1,11 +1,10 @@
-
 /* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
 
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -86,6 +85,8 @@ class EventSelection;
 class Event;
 class Clef;
 class ChordNameRuler;
+class QDeferScrollView;
+class HeadersGroup;
 
 
 /**
@@ -105,7 +106,7 @@ class NotationView : public EditView,
     friend class ClefInserter;
     friend class NotationEraser;
     friend class NotationSelectionPaster;
-    friend class LilypondExporter;
+    friend class LilyPondExporter;
 
     Q_OBJECT
 
@@ -166,6 +167,9 @@ public:
     /// Return a pointer to the staff corresponding to the given segment
     NotationStaff *getNotationStaff(const Segment &segment);
 
+    /// Return true if the staff at the specified index is the current one
+    bool isCurrentStaff(int i);
+
     QCanvas* canvas() { return getCanvasView()->canvas(); }
     
     void setCanvasCursor(const QCursor &cursor) {
@@ -204,6 +208,11 @@ public:
      */
     bool isInTripletMode();
 
+    /**
+     * Discover whether grace-mode insertions are enabled
+     */
+    bool isInGraceMode();
+
     /**
      * Discover whether annotations are being displayed or not
      */
@@ -212,7 +221,7 @@ public:
     /**
      * Discover whether LilyPond directives are being displayed or not
      */
-    bool areLilyPondDirectivesVisible() { return m_lilypondDirectivesVisible; }
+    bool areLilyPondDirectivesVisible() { return m_lilyPondDirectivesVisible; }
 
     /**
      * Set the current event selection.
@@ -255,6 +264,7 @@ public:
     void showPreviewNote(int staffNo, double layoutX,
                          int pitch, int height,
                          const Note &note,
+                         bool grace,
                          int velocity = -1);
 
     /// Remove any visible preview note
@@ -309,7 +319,26 @@ public:
      */
     virtual void print(bool previewOnly = false);
 
-    
+    /**
+     * Return X of the left of the canvas visible part.
+     */
+    double getCanvasLeftX() { return getCanvasView()->contentsX(); }
+
+    virtual RulerScale* getHLayout();
+
+    /**
+     * Return the notation window width
+     */
+    int getCanvasVisibleWidth();
+
+    /**
+     * Return the minimal width which shall be allocated to
+     * the track headers top frame.
+     * (The width of the close button + the width of an info
+     *  button still to come).
+     */
+    int getHeadersTopFrameMinWidth();
+
 public slots:
 
     /**
@@ -327,16 +356,16 @@ public slots:
     void slotFilePrintPreview();
 
     /**
-     * export a Lilypond file
+     * export a LilyPond file
      */
-    bool exportLilypondFile(QString url, bool forPreview = false);
+    bool exportLilyPondFile(QString url, bool forPreview = false);
 
     /**
      * Export to a temporary file and process
      */
-    void slotPrintLilypond();
-    void slotPreviewLilypond();
-    void slotLilypondViewProcessExited(KProcess *);
+    void slotPrintLilyPond();
+    void slotPreviewLilyPond();
+    void slotLilyPondViewProcessExited(KProcess *);
 
     /**
      * put the marked text/object into the clipboard and remove it
@@ -370,6 +399,16 @@ public slots:
      */
     void slotEditDelete();
 
+    /**
+     * move the selection to the staff above
+     */
+    void slotMoveEventsUpStaff();
+
+    /**
+     * move the selection to the staff below
+     */
+    void slotMoveEventsDownStaff();
+
     /**
      * toggles the tools toolbar
      */
@@ -406,7 +445,7 @@ public slots:
     void slotToggleGroupToolBar();
 
     /**
-     * toggles the font toolbar
+     * toggles the layout toolbar
      */
     void slotToggleLayoutToolBar();
 
@@ -478,6 +517,16 @@ public slots:
     void slotToggleLilyPondDirectives();
     void slotEditLyrics();
 
+    /// Notation header slots
+    void slotShowHeadersGroup();
+    void slotHideHeadersGroup();
+    void slotVerticalScrollHeadersGroup(int);
+    void slotUpdateHeaders(int x, int y);
+    void slotHeadersWidthChanged(int w);
+
+    /// Adjust notation header view when bottom ruler added or removed
+    void slotCanvasBottomWidgetHeightChanged(int);
+
     /// group slots
     void slotGroupBeam();
     void slotGroupAutoBeam();
@@ -486,8 +535,6 @@ public slots:
     void slotGroupGeneralTuplet();
     void slotGroupTuplet(bool simple);
     void slotGroupUnTuplet();
-    void slotGroupGrace();
-    void slotGroupUnGrace();
     void slotGroupSlur();
     void slotGroupPhrasingSlur();
     void slotGroupGlissando();
@@ -514,6 +561,9 @@ public slots:
     void slotTransformsSlursAbove();
     void slotTransformsSlursBelow();
     void slotTransformsRestoreSlurs();
+    void slotTransformsTiesAbove();
+    void slotTransformsTiesBelow();
+    void slotTransformsRestoreTies();
     void slotTransformsQuantize();
     void slotTransformsFixQuantization();
     void slotTransformsRemoveQuantization();
@@ -560,6 +610,7 @@ public slots:
     void slotEditAddSustainUp();
     void slotEditAddSustain(bool down);
     void slotEditTranspose();
+    void slotEditSwitchPreset();
     void slotEditElement(NotationStaff *, NotationElement *, bool advanced);
 
     void slotFinePositionLeft();
@@ -765,8 +816,8 @@ public slots:
     // Update notation view based on track/staff name change
     void slotUpdateStaffName();
 
-    // Lilypond Directive slots
-    void slotBeginLilypondRepeat();
+    // LilyPond Directive slots
+    void slotBeginLilyPondRepeat();
 
 signals:
     /**
@@ -814,8 +865,6 @@ signals:
 
 protected:
 
-    virtual RulerScale* getHLayout();
-
     virtual void paintEvent(QPaintEvent* e);
 
     /**
@@ -928,6 +977,9 @@ protected:
     virtual Segment *getCurrentSegment();
     virtual Staff *getCurrentStaff() { return getCurrentLinedStaff(); }
     virtual LinedStaff *getCurrentLinedStaff();
+
+    virtual LinedStaff *getStaffAbove();
+    virtual LinedStaff *getStaffBelow();
         
     virtual bool hasSegment(Segment *segment);
 
@@ -959,6 +1011,10 @@ protected:
 
     virtual void updateViewCaption();
 
+    void showHeadersGroup();
+    void hideHeadersGroup();
+
+
     //--------------- Data members ---------------------------------
 
     NotationProperties m_properties;
@@ -973,7 +1029,7 @@ protected:
     QLabel *m_annotationsLabel;
 
     /// Displayed in the status bar, shows when LilyPond directives are hidden
-    QLabel *m_lilypondDirectivesLabel;
+    QLabel *m_lilyPondDirectivesLabel;
 
     /// Displayed in the status bar, shows progress of current operation
     ProgressBar *m_progressBar;
@@ -1024,7 +1080,7 @@ protected:
     QWidget *m_tempoRuler;
     RawNoteRuler *m_rawNoteRuler;
     bool m_annotationsVisible;
-    bool m_lilypondDirectivesVisible;
+    bool m_lilyPondDirectivesVisible;
     
     KAction* m_selectDefaultNote;
 
@@ -1059,6 +1115,14 @@ protected:
     int m_printSize;
 
     static std::map<KProcess *, KTempFile *> m_lilyTempFileMap;
+
+    int m_showHeadersGroup;
+    QDeferScrollView * m_headersGroupView;
+    HeadersGroup * m_headersGroup;
+    QFrame * m_headersTopFrame;
+
+    KAction * m_showHeadersMenuEntry;
+
 };
 
 
