@@ -5,7 +5,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -112,7 +112,7 @@ public slots:
     /**
      * Scroll the view such that the numbered track is on-screen
      */
-    void slotScrollToTrack(int track);
+    void slotScrollToTrack(int trackPosition);
 
     /**
      * Set the position pointer during playback
