@@ -4,7 +4,7 @@
     Rosegarden
     A sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -23,9 +23,12 @@
 #ifndef _CLEF_INDEX_H_
 #define _CLEF_INDEX_H_
 
+#include "base/NotationTypes.h"
+#include <qstring.h>
+
 // used variously by TPB, SPB, PresetHandler to correlate combo box indices to
 // clef types
-enum { TrebleClef,                      // G clef, line 2
+enum { TrebleClef = 0,                  // G clef, line 2
        BassClef,                        // F clef, line 4
        CrotalesClef,                    // G clef, line 2, 15 above
        XylophoneClef,                   // G clef, line 2,  8 above
@@ -44,4 +47,13 @@ enum { TrebleClef,                      // G clef, line 2
        TwoBarClef                       // percussion clef  //!!! doesn't exist yet!
      };
 
+namespace Rosegarden 
+{
+
+const Clef clefIndexToClef(int index);
+
+const int clefNameToClefIndex(QString s);
+
+}
+
 #endif // _CLEF_INDEX_H_
