@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -84,6 +84,7 @@
 #include <kdockwidget.h>
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <kstddirs.h>
 #include <ktabwidget.h>
 #include <kxmlguiclient.h>
 #include <qaccel.h>
@@ -91,6 +92,7 @@
 #include <qdialog.h>
 #include <qframe.h>
 #include <qinputdialog.h>
+#include <qlabel.h>
 #include <qobjectlist.h>
 #include <qpopupmenu.h>
 #include <qsize.h>
@@ -123,6 +125,7 @@ EditView::EditView(RosegardenGUIDoc *doc,
         m_activeItem(0),
         m_canvasView(0),
         m_rulerBox(new QVBoxLayout),  // top ruler box - added to grid later on
+        m_rulerBoxFiller(0),          // On the left of m_rulerBox
         m_controlBox(new QVBoxLayout),  // top control ruler box - added to grid later on
         m_bottomBox(new QVBox(this, "bottomframe")),  // bottom box - added to bottom of canvas view by setCanvasView()
         m_topStandardRuler(0),
@@ -137,7 +140,19 @@ EditView::EditView(RosegardenGUIDoc *doc,
 
     (dynamic_cast<QBoxLayout*>(m_bottomBox->layout()))->setDirection(QBoxLayout::BottomToTop);
 
-    m_grid->addLayout(m_rulerBox, RULERS_ROW, m_mainCol);
+    // m_rulerBoxFiller is a white label used to keep m_rulerBox exactly
+    // above the scrolling part of the view (and never above the
+    // RosegardenCanvasView::m_leftWidget).
+    QGridLayout * gl = new QGridLayout(1, 2); 
+    gl->setColStretch(0, 0);
+    gl->setColStretch(1, 1);
+    gl->addLayout(m_rulerBox, 0, 1);
+    m_rulerBoxFiller = new QLabel(getCentralWidget());
+    gl->addWidget(m_rulerBoxFiller, 0, 0);
+    m_rulerBoxFiller->hide();
+
+    m_grid->addLayout(gl, RULERS_ROW, m_mainCol);
+
     m_grid->addMultiCellLayout(m_controlBox, CONTROLS_ROW, CONTROLS_ROW, 0, 1);
     m_controlBox->setAlignment(AlignRight);
     //     m_grid->addWidget(m_controlRulers, CONTROLRULER_ROW, 2);
@@ -251,11 +266,21 @@ void EditView::setControlRulersCurrentSegment()
     */
 }
 
-void EditView::setTopStandardRuler(StandardRuler* w)
+void EditView::setTopStandardRuler(StandardRuler* w, QWidget *leftBox)
 {
     delete m_topStandardRuler;
     m_topStandardRuler = w;
-    m_grid->addWidget(w, TOPBARBUTTONS_ROW, m_mainCol);
+
+    QGridLayout * gl = new QGridLayout(1, 2); 
+    gl->setColStretch(0, 0);
+    gl->setColStretch(1, 1);
+
+    gl->addWidget(w, 0, 1);
+    if (leftBox) {
+        gl->addWidget(leftBox, 0, 0);
+    }
+
+    m_grid->addLayout(gl, TOPBARBUTTONS_ROW, m_mainCol);
 
     if (m_canvasView) {
         connect(m_canvasView->horizontalScrollBar(), SIGNAL(valueChanged(int)),
@@ -695,24 +720,34 @@ EditView::setupActions()
 {
     createInsertPitchActionMenu();
 
-    new KAction(AddTempoChangeCommand::getGlobalName(), 0, this,
-                SLOT(slotAddTempo()), actionCollection(),
-                "add_tempo");
+    //
+    // Tempo and time signature changes
+    //
+    QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    QCanvasPixmap pixmap(pixmapDir + "/toolbar/event-insert-tempo.png");
+    QIconSet icon = QIconSet(pixmap);
+    new KAction(AddTempoChangeCommand::getGlobalName(),
+		icon, 0,
+		this, SLOT(slotAddTempo()),
+		actionCollection(), "add_tempo");
 
-    new KAction(AddTimeSignatureCommand::getGlobalName(), 0, this,
-                SLOT(slotAddTimeSignature()), actionCollection(),
-                "add_time_signature");
+    pixmap.load(pixmapDir + "/toolbar/event-insert-timesig.png");
+    icon = QIconSet(pixmap);
+    new KAction(AddTimeSignatureCommand::getGlobalName(),
+		icon, 0,
+		this, SLOT(slotAddTimeSignature()),
+		actionCollection(), "add_time_signature");
 
     //
     // Transforms
     //
-    new KAction(i18n("&Halve Speed"), Key_Less + CTRL, this,
-                SLOT(slotHalfSpeed()), actionCollection(),
-                "half_speed");
+    new KAction(i18n("&Halve Durations"), Key_H + CTRL, this,
+                SLOT(slotHalveDurations()), actionCollection(),
+                "halve_durations");
 
-    new KAction(i18n("&Double Speed"), Key_Greater + CTRL, this,
-                SLOT(slotDoubleSpeed()), actionCollection(),
-                "double_speed");
+    new KAction(i18n("&Double Durations"), Key_H + CTRL + SHIFT, this,
+                SLOT(slotDoubleDurations()), actionCollection(),
+                "double_durations");
 
     new KAction(RescaleCommand::getGlobalName(), 0, this,
                 SLOT(slotRescale()), actionCollection(),
@@ -1388,26 +1423,12 @@ EditView::slotClearControlRulerItem()
 }
 
 void
-EditView::slotHalfSpeed()
+EditView::slotHalveDurations()
 {
     if (!m_currentEventSelection)
         return ;
 
-    KTmpStatusMsg msg(i18n("Halving speed..."), this);
-
-    addCommandToHistory(
-        new RescaleCommand(*m_currentEventSelection,
-                           m_currentEventSelection->getTotalDuration() * 2,
-                           false));
-}
-
-void
-EditView::slotDoubleSpeed()
-{
-    if (!m_currentEventSelection)
-        return ;
-
-    KTmpStatusMsg msg(i18n("Doubling speed..."), this);
+    KTmpStatusMsg msg(i18n("Halving durations..."), this);
 
     addCommandToHistory(
         new RescaleCommand(*m_currentEventSelection,
@@ -1415,6 +1436,20 @@ EditView::slotDoubleSpeed()
                            false));
 }
 
+void
+EditView::slotDoubleDurations()
+{
+    if (!m_currentEventSelection)
+        return ;
+
+    KTmpStatusMsg msg(i18n("Doubling durations..."), this);
+
+    addCommandToHistory(
+        new RescaleCommand(*m_currentEventSelection,
+                           m_currentEventSelection->getTotalDuration() * 2,
+                           false));
+}
+
 void
 EditView::slotRescale()
 {
