@@ -5,7 +5,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -168,8 +168,8 @@ public slots:
     virtual void slotShowPropertyControlRuler();
 
     // rescale
-    void slotHalfSpeed();
-    void slotDoubleSpeed();
+    void slotHalveDurations();
+    void slotDoubleDurations();
     void slotRescale();
 
     // transpose
@@ -217,10 +217,10 @@ protected:
     virtual void paintEvent(QPaintEvent* e);
 
     /**
-     * Locate the given widget in the top bar-buttons position and
+     * Locate the given widgets in the top bar-buttons position and
      * connect up its scrolling signals.
      */
-    void setTopStandardRuler(StandardRuler*);
+    void setTopStandardRuler(StandardRuler*, QWidget *leftBox = NULL);
 
     /**
      * Locate the given widget in the bottom bar-buttons position and
@@ -383,6 +383,7 @@ protected:
     RosegardenCanvasView *m_canvasView;
 
     QVBoxLayout  *m_rulerBox;
+    QLabel       *m_rulerBoxFiller;
     QVBoxLayout  *m_controlBox;
     QVBox        *m_bottomBox;
     StandardRuler   *m_topStandardRuler;
