@@ -5,7 +5,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
 
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -111,6 +111,7 @@ public:
     static const char* const InsertCursor;
     static const char* const InsertCursorRuler;
 
+    static const char* const TrackDivider;
     static const char* const MovementGuide;
     static const char* const SelectionRectangle;
     static const char* const SelectedElement;
@@ -131,7 +132,7 @@ public:
 
     static const char* const TextAnnotationBackground;
 
-    static const char* const TextLilypondDirectiveBackground;
+    static const char* const TextLilyPondDirectiveBackground;
 
     static const char* const AudioCountdownBackground;
     static const char* const AudioCountdownForeground;
@@ -153,6 +154,8 @@ public:
 
     static const char* const MarkerBackground;
 
+    static const char* const QuickMarker;
+
     static const char* const MuteTrackLED;
     static const char* const RecordMIDITrackLED;
     static const char* const RecordAudioTrackLED;
