@@ -4,7 +4,7 @@
     Rosegarden
     A sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -45,7 +45,8 @@ KStartupLogo::KStartupLogo(QWidget * parent, const char *name)
                   WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Tool | WX11BypassWM | WWinOwnDC
 #endif
                  ),
-        m_readyToHide(false)
+	  m_readyToHide(false),
+	  m_showTip(true)
 {
     QString pixmapFile = locate("appdata", "pixmaps/splash.png");
     if (!pixmapFile)
@@ -81,7 +82,7 @@ void KStartupLogo::paintEvent(QPaintEvent*)
 
     // grep me: splash color
     //    QColor bg(49, 94, 19); // color for 2006 splash
-    QColor bg(19, 19, 19);  // color for the 2007 splash
+    QColor bg(19, 19, 19);  // color for the 2008 splash
     paint.setPen(bg);
     paint.setBrush(bg);
     paint.drawRect(QRect(m_pixmap.width() - 220, m_pixmap.height() - 43,
@@ -116,8 +117,10 @@ void KStartupLogo::close()
 {
     if (!m_wasClosed && isVisible()) {
 
-        RG_DEBUG << "KStartupLogo::close: Showing Tips\n";
-        KTipDialog::showTip(locate("data", "rosegarden/tips"));
+	if (m_showTip) {
+	    RG_DEBUG << "KStartupLogo::close: Showing Tips\n";
+	    KTipDialog::showTip(locate("data", "rosegarden/tips"));
+	}
     }
 
     QWidget::close();
