@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -199,7 +199,8 @@ MarkerRuler::slotDeleteMarker()
     Rosegarden::Marker* marker = getMarkerAtClickPosition();
     
     if (marker)
-        emit deleteMarker(marker->getTime(),
+        emit deleteMarker(marker->getID(),
+                          marker->getTime(),
                           marker->getName(),
                           marker->getDescription());                          
 }
@@ -222,6 +223,7 @@ MarkerRuler::slotEditMarker()
     if (dialog.exec() == QDialog::Accepted) {
         ModifyMarkerCommand *command =
             new ModifyMarkerCommand(&m_doc->getComposition(),
+                                    marker->getID(),
                                     dialog.getOriginalTime(),
                                     dialog.getTime(),
                                     qstrtostr(dialog.getName()),
