@@ -4,7 +4,7 @@
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <richard.bown@ferventsoftware.com>
@@ -60,7 +60,6 @@ StandardRuler::StandardRuler(RosegardenGUIDoc *doc,
         m_rulerScale(rulerScale),
         m_hButtonBar(0)
 {
-
     setSpacing(0);
 
     if (!m_invert) {
@@ -69,7 +68,7 @@ StandardRuler::StandardRuler(RosegardenGUIDoc *doc,
     }
 
     m_loopRuler = new LoopRuler
-                  (m_rulerScale, m_loopRulerHeight, xorigin, m_invert, this);
+                  (m_doc, m_rulerScale, m_loopRulerHeight, xorigin, m_invert, this, name);
 
     if (m_invert) {
         m_hButtonBar = new MarkerRuler
@@ -113,8 +112,8 @@ void StandardRuler::connectRulerToDocPointer(RosegardenGUIDoc *doc)
      RosegardenGUIApp::self(), SLOT(slotAddMarker(timeT)));
 
     QObject::connect
-    (m_hButtonBar, SIGNAL(deleteMarker(timeT, QString, QString)),
-     RosegardenGUIApp::self(), SLOT(slotDeleteMarker(timeT, QString, QString)));
+    (m_hButtonBar, SIGNAL(deleteMarker(int, timeT, QString, QString)),
+     RosegardenGUIApp::self(), SLOT(slotDeleteMarker(int, timeT, QString, QString)));
 
     QObject::connect
     (m_loopRuler, SIGNAL(dragPointerToPosition(timeT)),
