@@ -5,7 +5,7 @@
     Rosegarden
     A sequencer and musical notation editor.
  
-    This program is Copyright 2000-2007
+    This program is Copyright 2000-2008
         Guillaume Laurent   <glaurent@telegraph-road.org>,
         Chris Cannam        <cannam@all-day-breakfast.com>,
         Richard Bown        <bownie@bownie.com>
@@ -1754,8 +1754,6 @@ JackDriver::stopTransport()
     std::cerr << "\nJackDriver::stop: frames this play: " << framesThisPlay << ", elapsed " << (endTime - startTime) << std::endl;
 #endif
 
-    //!!!    flushAudio();
-
     if (m_jackTransportEnabled) {
 
         // Where did this request come from?  Is this a result of our
@@ -1957,28 +1955,6 @@ JackDriver::prebufferAudio()
     }
 }
 
-void
-JackDriver::flushAudio()
-{
-    if (!m_instrumentMixer)
-        return ;
-
-#ifdef DEBUG_JACK_DRIVER
-
-    std::cerr << "JackDriver::flushAudio" << std::endl;
-#endif
-
-    // to get async synth events agogo:
-
-    m_fileReader->fillBuffers(RealTime::zeroTime);
-
-    if (m_bussMixer->getBussCount() > 0) {
-        m_bussMixer->fillBuffers(RealTime::zeroTime);
-    } else {
-        m_instrumentMixer->fillBuffers(RealTime::zeroTime);
-    }
-}
-
 void
 JackDriver::kickAudio()
 {
@@ -2449,6 +2425,18 @@ JackDriver::getSynthPlugin(InstrumentId id)
         return 0;
 }
 
+void
+JackDriver::clearSynthPluginEvents()
+{
+    if (!m_instrumentMixer) return;
+
+#ifdef DEBUG_JACK_DRIVER
+    std::cerr << "JackDriver::clearSynthPluginEvents" << std::endl;
+#endif
+
+    m_instrumentMixer->discardPluginEvents();
+}
+
 bool
 JackDriver::openRecordFile(InstrumentId id,
                            const std::string &filename)
