@@ -4,7 +4,7 @@
   Rosegarden
   A sequencer and musical notation editor.
 
-  This program is Copyright 2000-2007
+  This program is Copyright 2000-2008
   Guillaume Laurent   <glaurent@telegraph-road.org>,
   Chris Cannam        <cannam@all-day-breakfast.com>,
   Richard Bown        <bownie@bownie.com>
@@ -193,6 +193,8 @@ public:
         FailureJackRestartFailed = 9,
         // A necessary ALSA call has returned an error code
         FailureALSACallFailed    = 10,
+        // Using a timer that has too low a resolution, but RTC might work
+        WarningImpreciseTimerTryRTC = 11,
     } FailureCode;      
 
     MappedEvent(): m_trackId(0),
